==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>録画が進行中です。ウィンドウを閉じてもよろしいですか?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">フォルダを開く</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>写真</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>動画</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>カメラ切替</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>フォルダを開く</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>印刷</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>このフォルダを操作する権限がありません</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">無効なフォルダです</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>フォルダを開く</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基本</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>保存先</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>撮影</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>撮影モード</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>セルフタイマー</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>出力</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>出力形式</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4枚</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10枚</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>カメラは、PCのWebカメラ等を使用して写真または動画を記録するためのユーティリティーです。</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ファイルが保存されませんでした</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">保存先:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>写真:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>動画:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>解像度</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">解像度:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>写真:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>動画:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>シャッター音</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>ミラーモード</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>フラッシュライト</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>最大解像度:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>録画停止</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>印刷</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>ショートカットを表示</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>撮影停止</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>コンテキストメニュー</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">撮影</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">録画開始</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">撮影停止</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>標準</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>ビビッド</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>暖かい</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>冷たい</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>レトロ</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>フィルム</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>グレー</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>フラッシュライト</translation>
    </message>
    <message>
        <source>On</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>セルフタイマー</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>フィルター</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>露出</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>カメラが見つかりませんでした</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>カメラは使用中です</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">録画停止</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.35.tar.xz: BUILD/src/translations/deepin-camera_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>録画が進行中です。ウィンドウを閉じてもよろしいですか?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">フォルダを開く</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>写真</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>動画</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>カメラ切替</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>フォルダを開く</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>印刷</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>このフォルダを操作する権限がありません</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">無効なフォルダです</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>フォルダを開く</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基本</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>保存先</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>撮影</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>撮影モード</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>セルフタイマー</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>出力</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>出力形式</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4枚</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10枚</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>カメラは、PCのWebカメラ等を使用して写真または動画を記録するためのユーティリティーです。</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ファイルが保存されませんでした</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">保存先:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>写真:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>動画:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>解像度</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">解像度:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>写真:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>動画:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>シャッター音</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>ミラーモード</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>フラッシュライト</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>最大解像度:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>カメラ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>録画停止</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>印刷</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>ショートカットを表示</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>撮影停止</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>コンテキストメニュー</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">撮影</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">録画開始</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">撮影停止</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>webm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>標準</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>ビビッド</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>暖かい</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>冷たい</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>レトロ</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>フィルム</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>グレー</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>フラッシュライト</translation>
    </message>
    <message>
        <source>On</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>セルフタイマー</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>フィルター</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>露出</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>カメラが見つかりませんでした</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>カメラは使用中です</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">録画停止</translation>
    </message>
</context>
</TS>
